from setuptools import setup

setup(name='tia_distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['tia_distributions'],
      author='Iddi Abdul Aziz',
      author_email='iddiabdulaziz1@gmail.com',
   zip_safe=False)